@@ -9,7 +9,8 @@ from sys import argv
 from os import environ
 
 
-def askpass():
+def askpass() -> None:
+    """Helper method that is automatically called when running git commands that may need credentials"""
     if 'username' in argv[1].lower():
         print(environ['OVERLEAF_EMAIL'])
         exit()
