@@ -8,13 +8,13 @@ from gigaleaf.linkedfiles.csv import CsvFile
 
 
 def load_linked_file(metadata_filename: str) -> Union[ImageFile, CsvFile]:
-    """
+    """Helper to load a LinkedFile child instance from an metadata file absolute path
 
     Args:
-        metadata_filename:
+        metadata_filename: Absolute path to a metadata file
 
     Returns:
-
+        LinkedFile child class instance
     """
     if not Path(metadata_filename).is_file():
         raise ValueError(f"Failed to load linked file: {metadata_filename}")
@@ -31,7 +31,7 @@ def load_linked_file(metadata_filename: str) -> Union[ImageFile, CsvFile]:
 
 
 def load_all_linked_files(overleaf_project_dir: str) -> List[Union[ImageFile, CsvFile]]:
-    """
+    """Helper to load all LinkedFile child instances for a given Overleaf Project
 
     Args:
         overleaf_project_dir:
